@@ -5,7 +5,7 @@
 *-----------------------------------------------------------------------
       SUBROUTINE SZSIDX(INDEX)
 
-      LOGICAL   LFRST,LWDATR,LCLATR
+      LOGICAL   LFRST,LWDATR,LCLATR,LFCATR
 
       SAVE
 
@@ -39,7 +39,7 @@
 
       CALL SWSWDI(IWDIDX)
       CALL SWQFCC(LFCATR)
-      CALL SWSCLI(ICLIDX,LFCATR)
+      CALL SWSCLI(ICLIDX,.NOT.LFCATR)
 
       RETURN
 *-----------------------------------------------------------------------
