@@ -9,7 +9,6 @@
 
       INTEGER   ICPAT(MAXCLI)
       LOGICAL   LFRST,LTNATR,LCLATR,LSOFTF,LHARD,LCL2TN,LMONOF,LMSG
-      LOGICAL   LCLCNV
       CHARACTER CMSG*80
 
       SAVE
@@ -49,26 +48,21 @@
 
       END IF
 
-*     / SOFT FILL OR HARD FILL /
+*     / SOFT FILL OR HARD FILL (FORCE TO SOFT FILL) /
 
       CALL SGLGET('LSOFTF',LSOFTF)
 
+      LHARD=.FALSE.
       IF (LSOFTF) THEN
-        LHARD=.FALSE.
       ELSE
-        IF (LTNATR) THEN
-          LHARD=.TRUE.
-        ELSE
-          LHARD=.FALSE.
-          IF (LMSG) THEN
-            CALL MSGDMP('W','SZSTNI','HARD FILL IS NOT SUPPORTED.')
-            LMSG=.FALSE.
-          END IF
+        LSOFTF=.TRUE.
+        LHARD=.FALSE.
+        IF (LMSG) THEN
+          CALL MSGDMP('W','SZSTNI','HARD FILL IS OBSOLETE.SOFT FILLED')
+          LMSG=.FALSE.
         END IF
       END IF
 
-      CALL SZSTMD(LHARD)
-
 *     / COLOR TO TONE CONVERSION /
 
       IF (LMONOF) THEN
@@ -96,15 +90,17 @@
       IF (ITCLIY.EQ.IBGCLI) THEN
         ITPATY=ITPNMY
       ELSE
-        CALL SGLGET('LCLCNV',LCLCNV)
-        IF (LCLCNV) THEN
-          IF (ITCLIY.EQ.0) ITCLIY=1
-        END IF
+        IF (ITCLIY.EQ.0) ITCLIY=1
         ITPATY=ITPNMY+ITCLIY*1000
       END IF
 
+      IF (ITPNMY .EQ. 999) THEN
+        LHARD=.TRUE.
+      END IF
+      CALL SZSTMD(LHARD)
+
       IF (LHARD) THEN
-        CALL SZTITZ(ITPATY)
+        CALL SZTITZ(ITPATZ)
       ELSE
         CALL SZTITS(ITPATY)
       END IF
