@@ -18,6 +18,7 @@
 
       EXTERNAL  IUETON, IUWGX, IUWGY
 
+      CALL SGIGET('IBGCLI',IBGCLI)
 
 *     / CHECK IMAGE CAPABILITY /
 
@@ -102,6 +103,9 @@
               ELSE
                 IF (TL1(1) .LE. ZZ .AND. ZZ .LE. TL2(NT)) THEN
                   IMAGE(I) = IUETON(ZZ)/1000
+                  IF(IMAGE(I) .EQ. IBGCLI) THEN
+                    IMAGE(I)=0
+                  ENDIF
                 ELSE
                   IMAGE(I) = 0
                 END IF
